@@ -17,8 +17,12 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.8.14 (database v22.24)',
-	'GNUmed 1.8.14 Release Notes:
+	'Release Notes for GNUmed 1.8.15 (database v22.25)',
+	'GNUmed 1.8.15 Release Notes:
+
+	1.8.15
+
+IMPROVED: person search: query speed
 
 	1.8.14
 
@@ -27,6 +31,10 @@ FIX: plugins: exception on raising configured but unloaded plugin
 IMPROVED: SOAP: on patient change ask if unsaved SOAP [thanks Marc]
 IMPROVED: DB: setup connections for auto_explain in --debug mode
 
+	22.25
+
+IMPROVED: identity/names: indices
+
 	22.24
 
 IMPROVED: blobs: indices [thanks Marc]
@@ -35,4 +43,4 @@ FIX: waiting list: failure in function moving entries
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.24@1.8.14');
+select gm.log_script_insertion('v22-release_notes-fixup.sql', '22.25@1.8.15');
